class NoAccessTokenProvided(Exception):
    def __init__(self) -> None:
        super().__init__("Genius Access Token is not Provided")


class ArtistNotFound(Exception):
    def __init__(self, artist: str) -> None:
        super().__init__(f"Artist {artist} not found")



from search_lyrics.main import search_lyrics
from search_lyrics.entrypoint import entrypoint as search_lyrics_entrypoint
from search_lyrics.__version__ import __version__

version = __version__

__all__ = ["search_lyrics", "search_lyrics_entrypoint", "__version__"]
